==> node-typescript_2.1.5.orig.tar.gz: TypeScript-2.1.5/tests/baselines/reference/assignmentCompatWithCallSignatures6.js <==
//// [assignmentCompatWithCallSignatures6.ts]
// checking assignment compatibility relations for function types. All valid

class Base { foo: string; }
class Derived extends Base { bar: string; }
class Derived2 extends Derived { baz: string; }
class OtherDerived extends Base { bing: string; }

interface A {
    a: <T>(x: T) => T[];
    a2: <T>(x: T) => string[];
    a3: <T>(x: T) => void;
    a4: <T,U>(x: T, y: U) => string;
    a5: <T,U>(x: (arg: T) => U) => T;
    a6: <T extends Base>(x: (arg: T) => Derived) => T;
    a11: <T>(x: { foo: T }, y: { foo: T; bar: T }) => Base;
    a15: <T>(x: { a: T; b: T }) => T[];
    a16: <T extends Base>(x: { a: T; b: T }) => T[];
}

var x: A;

var b: <T>(x: T) => T[]; 
x.a = b;
b = x.a;
var b2: <T>(x: T) => string[]; 
x.a2 = b2;
b2 = x.a2;
var b3: <T>(x: T) => T;
x.a3 = b3;
b3 = x.a3;
var b4: <T, U>(x: T, y: U) => string; 
x.a4 = b4;
b4 = x.a4;
var b5: <T, U>(x: (arg: T) => U) => T; 
x.a5 = b5;
b5 = x.a5;
var b11: <T, U>(x: { foo: T }, y: { foo: U; bar: U }) => Base; 
x.a11 = b11;
b11 = x.a11;
var b16: <T>(x: { a: T; b: T }) => T[]; 
x.a16 = b16;
b16 = x.a16;

//// [assignmentCompatWithCallSignatures6.js]
// checking assignment compatibility relations for function types. All valid
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Base = (function () {
    function Base() {
    }
    return Base;
}());
var Derived = (function (_super) {
    __extends(Derived, _super);
    function Derived() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Derived;
}(Base));
var Derived2 = (function (_super) {
    __extends(Derived2, _super);
    function Derived2() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Derived2;
}(Derived));
var OtherDerived = (function (_super) {
    __extends(OtherDerived, _super);
    function OtherDerived() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return OtherDerived;
}(Base));
var x;
var b;
x.a = b;
b = x.a;
var b2;
x.a2 = b2;
b2 = x.a2;
var b3;
x.a3 = b3;
b3 = x.a3;
var b4;
x.a4 = b4;
b4 = x.a4;
var b5;
x.a5 = b5;
b5 = x.a5;
var b11;
x.a11 = b11;
b11 = x.a11;
var b16;
x.a16 = b16;
b16 = x.a16;

==> node-typescript_3.0.3.orig.tar.gz: TypeScript-3.0.3/tests/baselines/reference/assignmentCompatWithCallSignatures6.js <==
//// [assignmentCompatWithCallSignatures6.ts]
// checking assignment compatibility relations for function types. All valid

class Base { foo: string; }
class Derived extends Base { bar: string; }
class Derived2 extends Derived { baz: string; }
class OtherDerived extends Base { bing: string; }

interface A {
    a: <T>(x: T) => T[];
    a2: <T>(x: T) => string[];
    a3: <T>(x: T) => void;
    a4: <T,U>(x: T, y: U) => string;
    a5: <T,U>(x: (arg: T) => U) => T;
    a6: <T extends Base>(x: (arg: T) => Derived) => T;
    a11: <T>(x: { foo: T }, y: { foo: T; bar: T }) => Base;
    a15: <T>(x: { a: T; b: T }) => T[];
    a16: <T extends Base>(x: { a: T; b: T }) => T[];
}

var x: A;

var b: <T>(x: T) => T[]; 
x.a = b;
b = x.a;
var b2: <T>(x: T) => string[]; 
x.a2 = b2;
b2 = x.a2;
var b3: <T>(x: T) => T;
x.a3 = b3;
b3 = x.a3;
var b4: <T, U>(x: T, y: U) => string; 
x.a4 = b4;
b4 = x.a4;
var b5: <T, U>(x: (arg: T) => U) => T; 
x.a5 = b5;
b5 = x.a5;
var b11: <T, U>(x: { foo: T }, y: { foo: U; bar: U }) => Base; 
x.a11 = b11;
b11 = x.a11;
var b16: <T>(x: { a: T; b: T }) => T[]; 
x.a16 = b16;
b16 = x.a16;

//// [assignmentCompatWithCallSignatures6.js]
// checking assignment compatibility relations for function types. All valid
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var Base = /** @class */ (function () {
    function Base() {
    }
    return Base;
}());
var Derived = /** @class */ (function (_super) {
    __extends(Derived, _super);
    function Derived() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Derived;
}(Base));
var Derived2 = /** @class */ (function (_super) {
    __extends(Derived2, _super);
    function Derived2() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return Derived2;
}(Derived));
var OtherDerived = /** @class */ (function (_super) {
    __extends(OtherDerived, _super);
    function OtherDerived() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return OtherDerived;
}(Base));
var x;
var b;
x.a = b;
b = x.a;
var b2;
x.a2 = b2;
b2 = x.a2;
var b3;
x.a3 = b3;
b3 = x.a3;
var b4;
x.a4 = b4;
b4 = x.a4;
var b5;
x.a5 = b5;
b5 = x.a5;
var b11;
x.a11 = b11;
b11 = x.a11;
var b16;
x.a16 = b16;
b16 = x.a16;
